@@ -32,7 +32,7 @@
 // proj_config.h must be included before testing HAVE_LIBDL
 #include "proj_config.h"
 
-#if defined(HAVE_LIBDL) && !defined(_GNU_SOURCE)
+#if defined(__CYGWIN__) && defined(HAVE_LIBDL) && !defined(_GNU_SOURCE)
 // Required for dladdr() on Cygwin
 #define _GNU_SOURCE
 #endif
@@ -1134,13 +1134,15 @@ void proj_context_set_sqlite3_vfs_name(PJ_CONTEXT *ctx, const char *name) {
 
 // ---------------------------------------------------------------------------
 
-/** Get the PROJ user writable directory for datumgrid files.
+/** Get the PROJ user writable directory for downloadable resource files, such
+ * as datum shift grids.
  *
  * @param ctx PROJ context, or NULL
  * @param create If set to TRUE, create the directory if it does not exist
  * already.
  * @return The path to the PROJ user writable directory.
  * @since 7.1
+ * @see proj_context_set_user_writable_directory()
  */
 
 const char *proj_context_get_user_writable_directory(PJ_CONTEXT *ctx,
@@ -1215,6 +1217,40 @@ const char *proj_context_get_user_writable_directory(PJ_CONTEXT *ctx,
     return ctx->user_writable_directory.c_str();
 }
 
+// ---------------------------------------------------------------------------
+
+/** Set the PROJ user writable directory for downloadable resource files, such
+ * as datum shift grids.
+ *
+ * If not explicitly set, the following locations are used:
+ * <ul>
+ * <li>on Windows, ${LOCALAPPDATA}/proj</li>
+ * <li>on macOS, ${HOME}/Library/Application Support/proj</li>
+ * <li>on other platforms (Linux), ${XDG_DATA_HOME}/proj if XDG_DATA_HOME is
+ * defined. Else ${HOME}/.local/share/proj</li>
+ * </ul>
+ *
+ * @param ctx PROJ context, or NULL
+ * @param path Path to the PROJ user writable directory. If set to NULL, the
+ *             default location will be used.
+ * @param create If set to TRUE, create the directory if it does not exist
+ * already.
+ * @since 9.5
+ * @see proj_context_get_user_writable_directory()
+ */
+
+void proj_context_set_user_writable_directory(PJ_CONTEXT *ctx, const char *path,
+                                              int create) {
+    if (!ctx)
+        ctx = pj_get_default_ctx();
+    ctx->user_writable_directory = path ? path : "";
+    if (!path || create) {
+        proj_context_get_user_writable_directory(ctx, create);
+    }
+}
+
+// ---------------------------------------------------------------------------
+
 /** Get the URL endpoint to query for remote grids.
  *
  * @param ctx PROJ context, or NULL
@@ -1239,15 +1275,6 @@ const char *proj_context_get_url_endpoint(PJ_CONTEXT *ctx) {
 
 // ---------------------------------------------------------------------------
 
-void pj_context_set_user_writable_directory(PJ_CONTEXT *ctx,
-                                            const std::string &path) {
-    if (!ctx)
-        ctx = pj_get_default_ctx();
-    ctx->user_writable_directory = path;
-}
-
-// ---------------------------------------------------------------------------
-
 #ifdef WIN32
 static const char dir_chars[] = "/\\";
 #else
