@@ -108,12 +108,12 @@ static const ParamMapping paramLongitudeFalseOrigin = {
     EPSG_CODE_PARAMETER_LONGITUDE_FALSE_ORIGIN, WKT1_CENTRAL_MERIDIAN,
     common::UnitOfMeasure::Type::ANGULAR, lon_0};
 
-static const ParamMapping paramFalseEastingOrigin = {
+static const ParamMapping paramEastingFalseOrigin = {
     EPSG_NAME_PARAMETER_EASTING_FALSE_ORIGIN,
     EPSG_CODE_PARAMETER_EASTING_FALSE_ORIGIN, WKT1_FALSE_EASTING,
     common::UnitOfMeasure::Type::LINEAR, x_0};
 
-static const ParamMapping paramFalseNorthingOrigin = {
+static const ParamMapping paramNorthingFalseOrigin = {
     EPSG_NAME_PARAMETER_NORTHING_FALSE_ORIGIN,
     EPSG_CODE_PARAMETER_NORTHING_FALSE_ORIGIN, WKT1_FALSE_NORTHING,
     common::UnitOfMeasure::Type::LINEAR, y_0};
@@ -159,7 +159,7 @@ static const ParamMapping *const paramsTPEQD[] = {&paramLatFirstPoint,
 
 static const ParamMapping *const paramsTMG[] = {
     &paramLatitudeFalseOrigin, &paramLongitudeFalseOrigin,
-    &paramFalseEastingOrigin, &paramFalseNorthingOrigin, nullptr};
+    &paramEastingFalseOrigin, &paramNorthingFalseOrigin, nullptr};
 
 static const ParamMapping paramLatFalseOriginLatOfCenter = {
     EPSG_NAME_PARAMETER_LATITUDE_FALSE_ORIGIN,
@@ -171,22 +171,45 @@ static const ParamMapping paramLongFalseOriginLongOfCenter = {
     EPSG_CODE_PARAMETER_LONGITUDE_FALSE_ORIGIN, WKT1_LONGITUDE_OF_CENTER,
     common::UnitOfMeasure::Type::ANGULAR, lon_0};
 
-static const ParamMapping *const paramsAEA[] = {
+static const ParamMapping *const paramsAEA_EQDC[] = {
     &paramLatFalseOriginLatOfCenter,
     &paramLongFalseOriginLongOfCenter,
     &paramLatitude1stStdParallel,
     &paramLatitude2ndStdParallel,
-    &paramFalseEastingOrigin,
-    &paramFalseNorthingOrigin,
+    &paramEastingFalseOrigin,
+    &paramNorthingFalseOrigin,
     nullptr};
 
+static const ParamMapping paramLatitudeNatOriginLCC1SP = {
+    EPSG_NAME_PARAMETER_LATITUDE_OF_NATURAL_ORIGIN,
+    EPSG_CODE_PARAMETER_LATITUDE_OF_NATURAL_ORIGIN, WKT1_LATITUDE_OF_ORIGIN,
+    common::UnitOfMeasure::Type::ANGULAR, lat_1};
+
+static const ParamMapping *const paramsLCC1SP[] = {
+    &paramLatitudeNatOriginLCC1SP,
+    &paramLongitudeNatOrigin,
+    &paramScaleFactor,
+    &paramFalseEasting,
+    &paramFalseNorthing,
+    nullptr};
+
+static const ParamMapping *const paramsLCC1SPVariantB[] = {
+    &paramLatitudeNatOriginLCC1SP,
+    &paramScaleFactor,
+    &paramLatitudeFalseOrigin,
+    &paramLongitudeFalseOrigin,
+    &paramEastingFalseOrigin,
+    &paramNorthingFalseOrigin,
+    nullptr,
+};
+
 static const ParamMapping *const paramsLCC2SP[] = {
     &paramLatitudeFalseOrigin,
     &paramLongitudeFalseOrigin,
     &paramLatitude1stStdParallel,
     &paramLatitude2ndStdParallel,
-    &paramFalseEastingOrigin,
-    &paramFalseNorthingOrigin,
+    &paramEastingFalseOrigin,
+    &paramNorthingFalseOrigin,
     nullptr,
 };
 
@@ -198,7 +221,7 @@ static const ParamMapping paramEllipsoidScaleFactor = {
 static const ParamMapping *const paramsLCC2SPMichigan[] = {
     &paramLatitudeFalseOrigin,    &paramLongitudeFalseOrigin,
     &paramLatitude1stStdParallel, &paramLatitude2ndStdParallel,
-    &paramFalseEastingOrigin,     &paramFalseNorthingOrigin,
+    &paramEastingFalseOrigin,     &paramNorthingFalseOrigin,
     &paramEllipsoidScaleFactor,   nullptr,
 };
 
@@ -274,17 +297,17 @@ static const ParamMapping paramLonCentreLonCenterLonc = {
     common::UnitOfMeasure::Type::ANGULAR, lonc};
 
 static const ParamMapping paramAzimuth = {
-    EPSG_NAME_PARAMETER_AZIMUTH_INITIAL_LINE,
-    EPSG_CODE_PARAMETER_AZIMUTH_INITIAL_LINE, WKT1_AZIMUTH,
+    EPSG_NAME_PARAMETER_AZIMUTH_PROJECTION_CENTRE,
+    EPSG_CODE_PARAMETER_AZIMUTH_PROJECTION_CENTRE, WKT1_AZIMUTH,
     common::UnitOfMeasure::Type::ANGULAR, alpha};
 
 static const ParamMapping paramAngleToSkewGrid = {
     EPSG_NAME_PARAMETER_ANGLE_RECTIFIED_TO_SKEW_GRID,
     EPSG_CODE_PARAMETER_ANGLE_RECTIFIED_TO_SKEW_GRID, WKT1_RECTIFIED_GRID_ANGLE,
     common::UnitOfMeasure::Type::ANGULAR, gamma};
-static const ParamMapping paramScaleFactorInitialLine = {
-    EPSG_NAME_PARAMETER_SCALE_FACTOR_INITIAL_LINE,
-    EPSG_CODE_PARAMETER_SCALE_FACTOR_INITIAL_LINE, WKT1_SCALE_FACTOR,
+static const ParamMapping paramScaleFactorProjectionCentre = {
+    EPSG_NAME_PARAMETER_SCALE_FACTOR_PROJECTION_CENTRE,
+    EPSG_CODE_PARAMETER_SCALE_FACTOR_PROJECTION_CENTRE, WKT1_SCALE_FACTOR,
     common::UnitOfMeasure::Type::SCALE, k};
 
 static const ParamMapping *const paramsHomVariantA[] = {
@@ -292,7 +315,7 @@ static const ParamMapping *const paramsHomVariantA[] = {
     &paramLonCentreLonCenterLonc,
     &paramAzimuth,
     &paramAngleToSkewGrid,
-    &paramScaleFactorInitialLine,
+    &paramScaleFactorProjectionCentre,
     &paramFalseEasting,
     &paramFalseNorthing,
     nullptr};
@@ -312,7 +335,7 @@ static const ParamMapping *const paramsHomVariantB[] = {
     &paramLonCentreLonCenterLonc,
     &paramAzimuth,
     &paramAngleToSkewGrid,
-    &paramScaleFactorInitialLine,
+    &paramScaleFactorProjectionCentre,
     &paramFalseEastingProjectionCentre,
     &paramFalseNorthingProjectionCentre,
     nullptr};
@@ -339,7 +362,7 @@ static const ParamMapping *const paramsHomTwoPoint[] = {
     &paramLongPoint1,
     &paramLatPoint2,
     &paramLongPoint2,
-    &paramScaleFactorInitialLine,
+    &paramScaleFactorProjectionCentre,
     &paramFalseEastingProjectionCentre,
     &paramFalseNorthingProjectionCentre,
     nullptr};
@@ -348,11 +371,20 @@ static const ParamMapping *const paramsIMWP[] = {
     &paramLongitudeNatOrigin, &paramLatFirstPoint, &paramLatSecondPoint,
     &paramFalseEasting,       &paramFalseNorthing, nullptr};
 
-static const ParamMapping paramLongCentreLongCenter = {
-    EPSG_NAME_PARAMETER_LONGITUDE_OF_ORIGIN,
-    EPSG_CODE_PARAMETER_LONGITUDE_OF_ORIGIN, WKT1_LONGITUDE_OF_CENTER,
+static const ParamMapping paramLongCentre = {
+    EPSG_NAME_PARAMETER_LONGITUDE_PROJECTION_CENTRE,
+    EPSG_CODE_PARAMETER_LONGITUDE_PROJECTION_CENTRE, WKT1_LONGITUDE_OF_CENTER,
     common::UnitOfMeasure::Type::ANGULAR, lon_0};
 
+static const ParamMapping *const paramsLocalOrthographic[] = {
+    &paramLatCentreLatCenter,
+    &paramLongCentre,
+    &paramAzimuth,
+    &paramScaleFactorProjectionCentre,
+    &paramFalseEastingProjectionCentre,
+    &paramFalseNorthingProjectionCentre,
+    nullptr};
+
 static const ParamMapping paramColatitudeConeAxis = {
     EPSG_NAME_PARAMETER_COLATITUDE_CONE_AXIS,
     EPSG_CODE_PARAMETER_COLATITUDE_CONE_AXIS, WKT1_AZIMUTH,
@@ -371,6 +403,11 @@ static const ParamMapping paramScaleFactorPseudoStdParallel = {
     WKT1_SCALE_FACTOR, common::UnitOfMeasure::Type::SCALE,
     k}; /* ignored by PROJ currently */
 
+static const ParamMapping paramLongCentreLongCenter = {
+    EPSG_NAME_PARAMETER_LONGITUDE_OF_ORIGIN,
+    EPSG_CODE_PARAMETER_LONGITUDE_OF_ORIGIN, WKT1_LONGITUDE_OF_CENTER,
+    common::UnitOfMeasure::Type::ANGULAR, lon_0};
+
 static const ParamMapping *const krovakParameters[] = {
     &paramLatCentreLatCenter,
     &paramLongCentreLongCenter,
@@ -468,21 +505,16 @@ static const ParamMapping *const paramsLoxim[] = {
     &paramLatLoxim, &paramLongitudeNatOrigin, &paramFalseEasting,
     &paramFalseNorthing, nullptr};
 
-static const ParamMapping paramLongCentre = {
-    EPSG_NAME_PARAMETER_LONGITUDE_PROJECTION_CENTRE,
-    EPSG_CODE_PARAMETER_LONGITUDE_PROJECTION_CENTRE, WKT1_LONGITUDE_OF_CENTER,
-    common::UnitOfMeasure::Type::ANGULAR, lon_0};
-
 static const ParamMapping paramLabordeObliqueMercatorAzimuth = {
-    EPSG_NAME_PARAMETER_AZIMUTH_INITIAL_LINE,
-    EPSG_CODE_PARAMETER_AZIMUTH_INITIAL_LINE, WKT1_AZIMUTH,
+    EPSG_NAME_PARAMETER_AZIMUTH_PROJECTION_CENTRE,
+    EPSG_CODE_PARAMETER_AZIMUTH_PROJECTION_CENTRE, WKT1_AZIMUTH,
     common::UnitOfMeasure::Type::ANGULAR, "azi"};
 
 static const ParamMapping *const paramsLabordeObliqueMercator[] = {
     &paramLatCentreLatCenter,
     &paramLongCentre,
     &paramLabordeObliqueMercatorAzimuth,
-    &paramScaleFactorInitialLine,
+    &paramScaleFactorProjectionCentre,
     &paramFalseEasting,
     &paramFalseNorthing,
     nullptr};
@@ -557,7 +589,7 @@ static const ParamMapping *const paramsGeographicTopocentric[] = {
     &paramLatTopoOrigin, &paramLongTopoOrigin, &paramHeightTopoOriginWithH0,
     nullptr};
 
-static const MethodMapping projectionMethodMappings[] = {
+static const MethodMapping gProjectionMethodMappings[] = {
     {EPSG_NAME_METHOD_TRANSVERSE_MERCATOR, EPSG_CODE_METHOD_TRANSVERSE_MERCATOR,
      "Transverse_Mercator", "tmerc", nullptr, paramsNatOriginScaleK},
 
@@ -585,24 +617,21 @@ static const MethodMapping projectionMethodMappings[] = {
      paramsTMG},
 
     {EPSG_NAME_METHOD_ALBERS_EQUAL_AREA, EPSG_CODE_METHOD_ALBERS_EQUAL_AREA,
-     "Albers_Conic_Equal_Area", "aea", nullptr, paramsAEA},
+     "Albers_Conic_Equal_Area", "aea", nullptr, paramsAEA_EQDC},
+
+    // Variant used by Oracle WKT:
+    // https://lists.osgeo.org/pipermail/qgis-user/2024-June/054599.html
+    {EPSG_NAME_METHOD_ALBERS_EQUAL_AREA, EPSG_CODE_METHOD_ALBERS_EQUAL_AREA,
+     "Albers_Conical_Equal_Area", "aea", nullptr, paramsAEA_EQDC},
 
     {EPSG_NAME_METHOD_LAMBERT_CONIC_CONFORMAL_1SP,
      EPSG_CODE_METHOD_LAMBERT_CONIC_CONFORMAL_1SP,
-     "Lambert_Conformal_Conic_1SP", "lcc", nullptr,
-     []() {
-         static const ParamMapping paramLatLCC1SP = {
-             EPSG_NAME_PARAMETER_LATITUDE_OF_NATURAL_ORIGIN,
-             EPSG_CODE_PARAMETER_LATITUDE_OF_NATURAL_ORIGIN,
-             WKT1_LATITUDE_OF_ORIGIN, common::UnitOfMeasure::Type::ANGULAR,
-             lat_1};
+     "Lambert_Conformal_Conic_1SP", "lcc", nullptr, paramsLCC1SP},
 
-         static const ParamMapping *const x[] = {
-             &paramLatLCC1SP,    &paramLongitudeNatOrigin, &paramScaleFactor,
-             &paramFalseEasting, &paramFalseNorthing,      nullptr,
-         };
-         return x;
-     }()},
+    {EPSG_NAME_METHOD_LAMBERT_CONIC_CONFORMAL_1SP_VARIANT_B,
+     EPSG_CODE_METHOD_LAMBERT_CONIC_CONFORMAL_1SP_VARIANT_B,
+     nullptr, // no mapping to WKT1_GDAL
+     "lcc", nullptr, paramsLCC1SPVariantB},
 
     {EPSG_NAME_METHOD_LAMBERT_CONIC_CONFORMAL_2SP,
      EPSG_CODE_METHOD_LAMBERT_CONIC_CONFORMAL_2SP,
@@ -622,6 +651,13 @@ static const MethodMapping projectionMethodMappings[] = {
      // LCC 2SP
      paramsLCC2SP},
 
+    {EPSG_NAME_METHOD_AZIMUTHAL_EQUIDISTANT,
+     EPSG_CODE_METHOD_AZIMUTHAL_EQUIDISTANT, "Azimuthal_Equidistant", "aeqd",
+     nullptr, paramsAEQD},
+
+    // We don't actually implement the Modified variant of Azimuthal Equidistant
+    // but the exact one. The difference between both is neglectable in a few
+    // hundred of kilometers away from the center of projection
     {EPSG_NAME_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT,
      EPSG_CODE_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT, "Azimuthal_Equidistant",
      "aeqd", nullptr, paramsAEQD},
@@ -651,6 +687,12 @@ static const MethodMapping projectionMethodMappings[] = {
      EPSG_CODE_METHOD_HYPERBOLIC_CASSINI_SOLDNER, nullptr, "cass", "hyperbolic",
      paramsNatOrigin},
 
+    // Definition to be put before PROJ_WKT2_NAME_METHOD_EQUIDISTANT_CONIC
+    {EPSG_NAME_METHOD_EQUIDISTANT_CONIC, EPSG_CODE_METHOD_EQUIDISTANT_CONIC,
+     "Equidistant_Conic", "eqdc", nullptr, paramsAEA_EQDC},
+
+    // Definition before EPSG codified it. To be put after entry for
+    // EPSG_NAME_METHOD_EQUIDISTANT_CONIC
     {PROJ_WKT2_NAME_METHOD_EQUIDISTANT_CONIC, 0, "Equidistant_Conic", "eqdc",
      nullptr, paramsEQDC},
 
@@ -732,6 +774,13 @@ static const MethodMapping projectionMethodMappings[] = {
     {EPSG_NAME_METHOD_KROVAK, EPSG_CODE_METHOD_KROVAK, "Krovak", "krovak",
      "axis=swu", krovakParameters},
 
+    {EPSG_NAME_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED,
+     EPSG_CODE_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED, nullptr, "mod_krovak",
+     nullptr, krovakParameters},
+
+    {EPSG_NAME_METHOD_KROVAK_MODIFIED, EPSG_CODE_METHOD_KROVAK_MODIFIED,
+     nullptr, "mod_krovak", "axis=swu", krovakParameters},
+
     {EPSG_NAME_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA,
      EPSG_CODE_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA,
      "Lambert_Azimuthal_Equal_Area", "laea", nullptr, paramsLaea},
@@ -755,6 +804,9 @@ static const MethodMapping projectionMethodMappings[] = {
                                               // handled manually
      "webmerc", nullptr, paramsNatOrigin},
 
+    {EPSG_NAME_METHOD_MERCATOR_SPHERICAL, EPSG_CODE_METHOD_MERCATOR_SPHERICAL,
+     nullptr, "merc", "R_C", paramsNatOrigin},
+
     {PROJ_WKT2_NAME_METHOD_MOLLWEIDE, 0, "Mollweide", "moll", nullptr,
      paramsLongNatOrigin},
 
@@ -779,6 +831,9 @@ static const MethodMapping projectionMethodMappings[] = {
     {EPSG_NAME_METHOD_ORTHOGRAPHIC, EPSG_CODE_METHOD_ORTHOGRAPHIC,
      "Orthographic", "ortho", nullptr, paramsNatOrigin},
 
+    {EPSG_NAME_METHOD_LOCAL_ORTHOGRAPHIC, EPSG_CODE_METHOD_LOCAL_ORTHOGRAPHIC,
+     "Local Orthographic", "ortho", nullptr, paramsLocalOrthographic},
+
     {PROJ_WKT2_NAME_ORTHOGRAPHIC_SPHERICAL, 0, "Orthographic", "ortho", "f=0",
      paramsNatOrigin},
 
@@ -890,15 +945,15 @@ static const MethodMapping projectionMethodMappings[] = {
 };
 
 const MethodMapping *getProjectionMethodMappings(size_t &nElts) {
-    nElts =
-        sizeof(projectionMethodMappings) / sizeof(projectionMethodMappings[0]);
-    return projectionMethodMappings;
+    nElts = sizeof(gProjectionMethodMappings) /
+            sizeof(gProjectionMethodMappings[0]);
+    return gProjectionMethodMappings;
 }
 
 #define METHOD_NAME_CODE(method)                                               \
     { EPSG_NAME_METHOD_##method, EPSG_CODE_METHOD_##method }
 
-const struct MethodNameCode methodNameCodes[] = {
+const struct MethodNameCode methodNameCodesList[] = {
     // Projection methods
     METHOD_NAME_CODE(TRANSVERSE_MERCATOR),
     METHOD_NAME_CODE(TRANSVERSE_MERCATOR_SOUTH_ORIENTATED),
@@ -923,6 +978,7 @@ const struct MethodNameCode methodNameCodes[] = {
     METHOD_NAME_CODE(KROVAK),
     METHOD_NAME_CODE(LAMBERT_AZIMUTHAL_EQUAL_AREA),
     METHOD_NAME_CODE(POPULAR_VISUALISATION_PSEUDO_MERCATOR),
+    METHOD_NAME_CODE(MERCATOR_SPHERICAL),
     METHOD_NAME_CODE(MERCATOR_VARIANT_A),
     METHOD_NAME_CODE(MERCATOR_VARIANT_B),
     METHOD_NAME_CODE(OBLIQUE_STEREOGRAPHIC),
@@ -972,6 +1028,7 @@ const struct MethodNameCode methodNameCodes[] = {
     METHOD_NAME_CODE(GEOGRAPHIC2D_OFFSETS),
     METHOD_NAME_CODE(GEOGRAPHIC2D_WITH_HEIGHT_OFFSETS),
     METHOD_NAME_CODE(GEOGRAPHIC3D_OFFSETS),
+    METHOD_NAME_CODE(CARTESIAN_GRID_OFFSETS),
     METHOD_NAME_CODE(VERTICAL_OFFSET),
     METHOD_NAME_CODE(VERTICAL_OFFSET_AND_SLOPE),
     METHOD_NAME_CODE(NTV2),
@@ -981,17 +1038,19 @@ const struct MethodNameCode methodNameCodes[] = {
     METHOD_NAME_CODE(NADCON5_3D),
     METHOD_NAME_CODE(VERTCON),
     METHOD_NAME_CODE(GEOCENTRIC_TRANSLATION_BY_GRID_INTERPOLATION_IGN),
+    // PointMotionOperation
+    METHOD_NAME_CODE(POINT_MOTION_BY_GRID_CANADA_NTV2_VEL),
 };
 
 const MethodNameCode *getMethodNameCodes(size_t &nElts) {
-    nElts = sizeof(methodNameCodes) / sizeof(methodNameCodes[0]);
-    return methodNameCodes;
+    nElts = sizeof(methodNameCodesList) / sizeof(methodNameCodesList[0]);
+    return methodNameCodesList;
 }
 
 #define PARAM_NAME_CODE(method)                                                \
     { EPSG_NAME_PARAMETER_##method, EPSG_CODE_PARAMETER_##method }
 
-const struct ParamNameCode paramNameCodes[] = {
+const struct ParamNameCode gParamNameCodes[] = {
     // Parameters of projection methods
     PARAM_NAME_CODE(COLATITUDE_CONE_AXIS),
     PARAM_NAME_CODE(LATITUDE_OF_NATURAL_ORIGIN),
@@ -1001,9 +1060,9 @@ const struct ParamNameCode paramNameCodes[] = {
     PARAM_NAME_CODE(FALSE_NORTHING),
     PARAM_NAME_CODE(LATITUDE_PROJECTION_CENTRE),
     PARAM_NAME_CODE(LONGITUDE_PROJECTION_CENTRE),
-    PARAM_NAME_CODE(AZIMUTH_INITIAL_LINE),
+    PARAM_NAME_CODE(AZIMUTH_PROJECTION_CENTRE),
     PARAM_NAME_CODE(ANGLE_RECTIFIED_TO_SKEW_GRID),
-    PARAM_NAME_CODE(SCALE_FACTOR_INITIAL_LINE),
+    PARAM_NAME_CODE(SCALE_FACTOR_PROJECTION_CENTRE),
     PARAM_NAME_CODE(EASTING_PROJECTION_CENTRE),
     PARAM_NAME_CODE(NORTHING_PROJECTION_CENTRE),
     PARAM_NAME_CODE(LATITUDE_PSEUDO_STANDARD_PARALLEL),
@@ -1027,12 +1086,15 @@ const struct ParamNameCode paramNameCodes[] = {
     PARAM_NAME_CODE(LATITUDE_LONGITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(GEOID_CORRECTION_FILENAME),
     PARAM_NAME_CODE(VERTICAL_OFFSET_FILE),
+    PARAM_NAME_CODE(GEOID_MODEL_DIFFERENCE_FILE),
     PARAM_NAME_CODE(LATITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(LONGITUDE_DIFFERENCE_FILE),
     PARAM_NAME_CODE(UNIT_CONVERSION_SCALAR),
     PARAM_NAME_CODE(LATITUDE_OFFSET),
     PARAM_NAME_CODE(LONGITUDE_OFFSET),
     PARAM_NAME_CODE(VERTICAL_OFFSET),
+    PARAM_NAME_CODE(EASTING_OFFSET),
+    PARAM_NAME_CODE(NORTHING_OFFSET),
     PARAM_NAME_CODE(GEOID_UNDULATION),
     PARAM_NAME_CODE(A0),
     PARAM_NAME_CODE(A1),
@@ -1064,11 +1126,13 @@ const struct ParamNameCode paramNameCodes[] = {
     PARAM_NAME_CODE(INCLINATION_IN_LONGITUDE),
     PARAM_NAME_CODE(EPSG_CODE_FOR_HORIZONTAL_CRS),
     PARAM_NAME_CODE(EPSG_CODE_FOR_INTERPOLATION_CRS),
+    // Parameters of point motion operations
+    PARAM_NAME_CODE(POINT_MOTION_VELOCITY_GRID_FILE),
 };
 
 const ParamNameCode *getParamNameCodes(size_t &nElts) {
-    nElts = sizeof(paramNameCodes) / sizeof(paramNameCodes[0]);
-    return paramNameCodes;
+    nElts = sizeof(gParamNameCodes) / sizeof(gParamNameCodes[0]);
+    return gParamNameCodes;
 }
 
 static const ParamMapping paramUnitConversionScalar = {
@@ -1292,6 +1356,17 @@ static const ParamMapping paramVerticalOffset = {
 static const ParamMapping *const paramsGeographic3DOffsets[] = {
     &paramLatitudeOffset, &paramLongitudeOffset, &paramVerticalOffset, nullptr};
 
+static const ParamMapping paramEastingOffset = {
+    EPSG_NAME_PARAMETER_EASTING_OFFSET, EPSG_CODE_PARAMETER_EASTING_OFFSET,
+    nullptr, common::UnitOfMeasure::Type::LINEAR, nullptr};
+
+static const ParamMapping paramNorthingOffset = {
+    EPSG_NAME_PARAMETER_NORTHING_OFFSET, EPSG_CODE_PARAMETER_NORTHING_OFFSET,
+    nullptr, common::UnitOfMeasure::Type::LINEAR, nullptr};
+
+static const ParamMapping *const paramsCartesianGridOffsets[] = {
+    &paramEastingOffset, &paramNorthingOffset, nullptr};
+
 static const ParamMapping *const paramsVerticalOffsets[] = {
     &paramVerticalOffset, nullptr};
 
@@ -1360,6 +1435,14 @@ static const ParamMapping paramVerticalOffsetFile = {
 static const ParamMapping *const paramsVERTCON[] = {&paramVerticalOffsetFile,
                                                     nullptr};
 
+static const ParamMapping paramPointMotiionVelocityGridFile = {
+    EPSG_NAME_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE,
+    EPSG_CODE_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE, nullptr,
+    common::UnitOfMeasure::Type::NONE, nullptr};
+
+static const ParamMapping *const paramsPointMotionOperationByVelocityGrid[] = {
+    &paramPointMotiionVelocityGridFile, nullptr};
+
 static const ParamMapping paramSouthPoleLatGRIB = {
     PROJ_WKT2_NAME_PARAMETER_SOUTH_POLE_LATITUDE_GRIB_CONVENTION, 0, nullptr,
     common::UnitOfMeasure::Type::ANGULAR, nullptr};
@@ -1392,7 +1475,7 @@ static const ParamMapping *const paramsPoleRotationNetCDFCFConvention[] = {
     &paramGridNorthPoleLatitudeNetCDF, &paramGridNorthPoleLongitudeNetCDF,
     &paramNorthPoleGridLongitudeNetCDF, nullptr};
 
-static const MethodMapping otherMethodMappings[] = {
+static const MethodMapping gOtherMethodMappings[] = {
     {EPSG_NAME_METHOD_CHANGE_VERTICAL_UNIT,
      EPSG_CODE_METHOD_CHANGE_VERTICAL_UNIT, nullptr, nullptr, nullptr,
      paramsChangeVerticalUnit},
@@ -1517,6 +1600,10 @@ static const MethodMapping otherMethodMappings[] = {
      EPSG_CODE_METHOD_GEOGRAPHIC3D_OFFSETS, nullptr, nullptr, nullptr,
      paramsGeographic3DOffsets},
 
+    {EPSG_NAME_METHOD_CARTESIAN_GRID_OFFSETS,
+     EPSG_CODE_METHOD_CARTESIAN_GRID_OFFSETS, nullptr, nullptr, nullptr,
+     paramsCartesianGridOffsets},
+
     {EPSG_NAME_METHOD_VERTICAL_OFFSET, EPSG_CODE_METHOD_VERTICAL_OFFSET,
      nullptr, nullptr, nullptr, paramsVerticalOffsets},
 
@@ -1547,17 +1634,21 @@ static const MethodMapping otherMethodMappings[] = {
      nullptr, paramsVERTCON},
     {EPSG_NAME_METHOD_VERTCON_OLDNAME, EPSG_CODE_METHOD_VERTCON, nullptr,
      nullptr, nullptr, paramsVERTCON},
+
+    {EPSG_NAME_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL,
+     EPSG_CODE_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL, nullptr, nullptr,
+     nullptr, paramsPointMotionOperationByVelocityGrid},
 };
 
 const MethodMapping *getOtherMethodMappings(size_t &nElts) {
-    nElts = sizeof(otherMethodMappings) / sizeof(otherMethodMappings[0]);
-    return otherMethodMappings;
+    nElts = sizeof(gOtherMethodMappings) / sizeof(gOtherMethodMappings[0]);
+    return gOtherMethodMappings;
 }
 
 // ---------------------------------------------------------------------------
 
 PROJ_NO_INLINE const MethodMapping *getMapping(int epsg_code) noexcept {
-    for (const auto &mapping : projectionMethodMappings) {
+    for (const auto &mapping : gProjectionMethodMappings) {
         if (mapping.epsg_code == epsg_code) {
             return &mapping;
         }
@@ -1570,7 +1661,7 @@ PROJ_NO_INLINE const MethodMapping *getMapping(int epsg_code) noexcept {
 const MethodMapping *getMapping(const OperationMethod *method) noexcept {
     const std::string &name(method->nameStr());
     const int epsg_code = method->getEPSGCode();
-    for (const auto &mapping : projectionMethodMappings) {
+    for (const auto &mapping : gProjectionMethodMappings) {
         if ((epsg_code != 0 && mapping.epsg_code == epsg_code) ||
             metadata::Identifier::isEquivalentName(mapping.wkt2_name,
                                                    name.c_str())) {
@@ -1588,7 +1679,7 @@ const MethodMapping *getMappingFromWKT1(const std::string &wkt1_name) noexcept {
         return getMapping(EPSG_CODE_METHOD_TRANSVERSE_MERCATOR);
     }
 
-    for (const auto &mapping : projectionMethodMappings) {
+    for (const auto &mapping : gProjectionMethodMappings) {
         if (mapping.wkt1_name && metadata::Identifier::isEquivalentName(
                                      mapping.wkt1_name, wkt1_name.c_str())) {
             return &mapping;
@@ -1599,13 +1690,13 @@ const MethodMapping *getMappingFromWKT1(const std::string &wkt1_name) noexcept {
 // ---------------------------------------------------------------------------
 
 const MethodMapping *getMapping(const char *wkt2_name) noexcept {
-    for (const auto &mapping : projectionMethodMappings) {
+    for (const auto &mapping : gProjectionMethodMappings) {
         if (metadata::Identifier::isEquivalentName(mapping.wkt2_name,
                                                    wkt2_name)) {
             return &mapping;
         }
     }
-    for (const auto &mapping : otherMethodMappings) {
+    for (const auto &mapping : gOtherMethodMappings) {
         if (metadata::Identifier::isEquivalentName(mapping.wkt2_name,
                                                    wkt2_name)) {
             return &mapping;
@@ -1619,7 +1710,7 @@ const MethodMapping *getMapping(const char *wkt2_name) noexcept {
 std::vector<const MethodMapping *>
 getMappingsFromPROJName(const std::string &projName) {
     std::vector<const MethodMapping *> res;
-    for (const auto &mapping : projectionMethodMappings) {
+    for (const auto &mapping : gProjectionMethodMappings) {
         if (mapping.proj_name_main && projName == mapping.proj_name_main) {
             res.push_back(&mapping);
         }
